%algesurf
% Function which plots algebraic surfaces.
%
% Reference: http://www.freigeist.cc/gallery.html
%
% LAST UPDATED by Andy French April 2012.

function algesurf

FF_alpha = 0.7;
n=150;
k = 10;
x=linspace(-k,k,n);
y=linspace(-k,k,n);
z=linspace(-k,k,n);
[x,y,z]=meshgrid(x,y,z);
FF = linspace(0,100,5);

%Compute function at every point in mesh
F = (x+1).*z.^3 +7*z.^2 + z.*(y.^3 +5) +  y.*x.^3 ;
% F= x.^3 + (z.^2) .* (x.^2) - y.^2 ;
% F = x.^2 + y.^2 + z.^2 - 2;
% F = (x + sin(z) ).^2 + x.*y.^2.*z - z.*( y + cos(x) );
% F = x.^2 + 3*y.^2 + z.^2 - 1;
% F = x.^2 - x.^3 + y.^2 + y.^4 + z.^3 - z.^4;

for m=1:5;
    %Plot isosurfaces of F evaluated at the following points:
    vol( x,y,z,F,FF(m),FF_alpha,[0,1] );
    axis vis3d
    axis off
    lighting phong
    camlight
    
    %Save a 300dpi PNG file
    print(gcf,['asurf2',num2str(m)],'-dpng','-r300')
    cla;
end
close(gcf);

%%

function vol( x,y,z,V,v,t,cax )

%Point to current active figure, or create a new one if one doesn't exist.
fig = gcf;

%Make figure window white and set rendering option to OpenGL. Use ZBuffer
%if your graphics card doesn't support this.
set(fig,'color',[1 1 1],'renderer','opengl');

%Obtain maximum and minimum values of V
Vmax = max(max(max(V)));
Vmin = min(min(min(V)));

%Make sure v is within the range Vmin to Vmax
v(v>Vmax) = Vmax;
v(v<Vmin) = Vmin;

%Make sure t is within the range 0 to 1
t(t>1) = 1;
t(t<0) = 0;

%Set limits of V to correspond to colormap
if isempty(cax)==1
    caxis( [Vmin,Vmax] );
else
    caxis( cax );
end
    
%Visualize volume by plotting nested shells of volume iso-surfaces with
%varying transparency. Use current colormap to set the colour of the shells
for n=1:length(v)
    [R,G,B] = colfromcolormap( v(n) );
    p = patch( isosurface(x,y,z,V, v(n) ),...
        'Facealpha',t(n),'FaceColor', [R,G,B], 'EdgeColor', 'none');
    isonormals(x,y,z,V,p);
end
view(3); 
daspect([1 1 1]);

%%

%colfromcolormap
% Obtain colours corresponding to value x from curent colormap.

function [R,G,B] = colfromcolormap(x)

%Get vaiable range of current colormap
[xmin,xmax] = caxis;

%Get current colormap
map = colormap;
dim = size(map);

%Make sure x is within the caxis range
x(x>xmax) = xmax;
x(x<xmin) = xmin;

%Interpolate R,G,B values at x
R = interp1( linspace(xmin,xmax,dim(1)),map(:,1).',x );
G = interp1( linspace(xmin,xmax,dim(1)),map(:,2).',x );
B = interp1( linspace(xmin,xmax,dim(1)),map(:,3).',x );

%End of code