%bauble
% Function which loads a bitmap image and texture maps this to a sphere.
%
% LAST UPDATED by Andy French April 2016

function bauble

%Chose image file to load
[filename, pathname] = uigetfile( {'*.jpg;*.bmp;*.png;*.gif;*tif',...
    'Bitmap images (*.jpg,*.bmp,*.png,*.gif,*.tif)'},...
    'Select location of image file(s)...', ...
    'multiselect', 'off' );
if filename == 0
    return
end

%Load image into an NxMx3 matrix of values. i.e. Red, Green and Blue colour
%planes. cmap is the local colormap associated with the image, and alpha is
%a matrix which defines the transparency of the image
[I,cmap,alphamap] = imread( [pathname,filename] );

%Get image information stored within the file
info = imfinfo( [pathname,filename] );
dim = size(I);

%Set the colour matrix to be within the range 0...1, and a double precision
%number. Most full colour images are stored as 8 bit integers.
if numel(dim) == 2
    %An indexed image like a GIF has a colourmap rather than three R,G,B
    %colour intensities.
    I = 255*ind2rgb(I,cmap);
end
I = double(I)/255;

%Flip image, as pixel(1,1) is by convention the top left rather than the
%bottom left.
I = flipdim(I,1);

%Generate x,y,z matrices of a unit sphere
elev = linspace( -pi/2,pi/2,dim(1) );
azi = linspace( 0, 2*pi, dim(2) );
[azi,elev] = meshgrid(azi,elev);
x = cos(elev).*cos(azi);
y = cos(elev).*sin(azi);
z = sin(elev);

%Create a figure and plot the image
figure('color',[0 0 0],'name',filename)
surf( x,y,z,I);
shading interp;
axis vis3d
axis off;
zoom(1.5)

%Output JPEG image. Note this means changing the file extension
print( gcf, [pathname,'bauble ',strrep( filename, lower(info.Format),'jpg')],'-djpeg','-r300' );

%End of code