%epicycloid
% Draws a curve stitched epicycloid such as a cardiod, nephroid etc.
%
% LAST UPDATED by Andy French April 2016

function epicycloid

%Number of points on the circle
N = 128;

%Define input for epicyloid
sf = '7*n';

%

%Create epicycloid lines
[x,y] = epi_cycloid( N, sf);

%Plot epicycloid overlaid upon the unit circle
tt = linspace(0, 2*pi, 300);
xx = sin(tt);
yy = cos(tt);
figure('color',[1 1 1],'name','Epicycloid test','numbertitle','off')
plot(xx,yy,'k'); hold on;
plot( x,y,'b')
axis equal
axis off

%Add numbers
t = linspace( 2*pi/N, 2*pi, N );
xt = 1.06*sin(t);
yt = 1.06*cos(t);
for nn=1:N
    text( xt(nn),yt(nn),num2str(nn),...
        'Horizontalalignment','center','rotation',-t(nn)*180/pi,'fontsize',8 );
end

%Plot PNG file
print( gcf, ['epicycloid ',...
    strrep(datestr(now),':','-'),'.png'],'-dpng','-r300' );

%%

%epicycloid
% Function which returns line elements which can be used to create a
% 'curve stitched epicycloid'.
% 
% LAST UPDATED by Andy French April 2012
%
% Syntax: [x,y] = epicycloid( N, sf )
%
% N is the number of points around a unit circle which form the basis of
% the epicycloid.
% sf is a string which defines the number of points on the circle one
% advances from each point n as a function of n.
% 
% sf = '2*n'   Cardioid
% sf = '3*n'   Nephroid
% sf = '4*n'   Epicycloid of Cremona
%
% Note the numerical output of sf will be rounded and then evaluated modulo
% N. e.g. if N = 16 and sf yields 17.4, the output will be 1.
%
% x and y are 2 x K  matrices which describe the line segments which
% describe the rose. The first row is the starting coordinate and the
% second row is the end coordinate of each line segment.

function [x,y] = epi_cycloid( N, sf )

%Create vector of circle points and then evaluate the points these are
%joined to
n = 1:N;
eval( ['m=',sf,';'] );
m = mod( round(m)-1, N ) + 1;

%Create x,y points which define the circle
t = linspace( 2*pi/N, 2*pi, N );
xx = sin(t);
yy = cos(t);

%Construct x and y matrices which define epicycloid line segments
x = [xx(n);xx(m)];
y = [yy(n);yy(m)];

%%

function epicycloid_test



%End of code