%mysticrose
%
% LAST UPDATED by Andy French April 2016

function mysticrose

%Number of points around a circle
N = 15;

%Vector of indices which correspond to the points of the rose. The mystic 
%rose is formed by drawing straight lines from these points to all
%other points
% s = [1,3,5,7,9];
s = 1:N;

%

%Create mystic rose
[x,y] = mystic_rose( N, s);
figure('color',[1 1 1],'name','Mystic rose','numbertitle','off')
plot( x,y,'b')
axis equal
axis off
hold on

%Add numbers
t = linspace( 2*pi/N, 2*pi, N );
xt = 1.06*sin(t);
yt = 1.06*cos(t);
for nn=1:N
    text( xt(nn),yt(nn),num2str(nn),...
        'Horizontalalignment','center','rotation',-t(nn)*180/pi,'fontsize',8 );
end

%Plot PNG file
print( gcf, ['mysticrose ',...
    strrep(datestr(now),':','-'),'.png'],'-dpng','-r300' );

%%

%mystic_rose
% Function which returns the line elements which can be used to plot a
% mystic rose.
%
% LAST UPDATED by Andy French April 2012
%
% Syntax: [x,y] = mystic_rose( N, s )
%
% N is the number of points around a unit circle which form the basis of
% the mystic rose
% s is a vector of indices which correspond to the points of the rose. The
% mystic rose is formed by drawing straight lines from these points to all
% other points. Note any element of s which is duplicate or not in the set
% 1:N will be ignored.
% x and y are 2 x K  matrices which describe the line segments which
% describe the rose. The first row is the starting coordinate and the
% second row is the end coordinate of each line segment.

function [x,y] = mystic_rose( N, s)

%Initialise outputs
x = [];
y = [];

%Remove elements of s which don't belong to 1:N. Also remove duplicates
s = intersect( unique(s), 1:N );
if isempty(s)
    return
end

%Create x,y points which define the unit circle
t = linspace( 2*pi/N, 2*pi, N );
xx = sin(t);
yy = cos(t);

%For each element of s, construct line segments of the mystic rose
for m=1:length(s)
    for n=1:N
        if n~=s(m)
            %Draw lines from point s(m) to all other points on the circle
            x = [ x , [xx(s(m)); xx(n)] ];
            y = [ y , [yy(s(m)); yy(n)] ];
        end
    end
end

%End of code