%import_elements
% Imports data from Excel file Elements concerning the elements in the
% Periodic table. Data is saved as a series of vectors (either numeric or
% cell) in a .mat file elements.mat
%
% LAST UPDATED by Andy French March 2016

function import_elements

%Number of elements
N = 118;

%Load Excel file
disp(' ')
t0=tic;
disp(' Importing periodic table data from Elements.xls ....')
[num,txt,raw] = xlsread('Elements.xls');

%Initialize outputs
Z = ones(1,N);
M = ones(1,N);
element = cell(1,N);
element_symbol = cell(1,N);
melting_point_degC = ones(1,N);
boiling_point_degC = ones(1,N);
density_g_per_cm3 = ones(1,N);
earth_abundance_percentage = ones(1,N);
discovery_year = ones(1,N);
group = ones(1,N);
electron_configuration = cell(1,N);
ionization_energy_eV = ones(1,N);

%Step through data and assign output elements
for n=1:N
    Z(n) = raw{n+1,1};
    M(n) = raw{n+1,2};
    element{n} = raw{n+1,3};
    element_symbol{n} = raw{n+1,4};
    melting_point_degC(n) = raw{n+1,5};
    boiling_point_degC(n) = raw{n+1,6};
    density_g_per_cm3(n) = raw{n+1,7};
    earth_abundance_percentage(n) = raw{n+1,8};
    if strcmp( raw{n+1,9}, 'ancient' )
        discovery_year(n) = NaN;
    else
        discovery_year(n) = raw{n+1,9};
    end
    group(n) = raw{n+1,10};
    electron_configuration{n} = raw{n+1,11};
    ionization_energy_eV(n) = raw{n+1,12};
end

%Save .mat file
clear num txt raw n N
save elements
disp([' Data imported and saved to file elements.mat in ',num2str(toc(t0)),'s.']);
disp(' ');

%End of code