%plot_binding_energy_per_nucleon_vs_A

function plot_binding_energy_per_nucleon_vs_A

%Fontsize for plots
fsize = 16;

%

%Load Z, A and binding energy data
d = load('nubase.mat');
e = load('elements.mat');

%Calculate binding energy as per liquid drop model
B_model = liquid_drop_model( d.A-d.Z,d.Z );
B_model_average = liquid_drop_model( e.M-e.Z,e.Z );

%Plot binding energy per nucleon vs A
figure('name','binding energy per nucleon vs A' ,'color',[1 1 1] )
plot(-1,-1,'b.','markersize',10,'markerfacecolor','r'); hold on
plot(-1,-1,'r.','markersize',10,'markerfacecolor','r');
plot( e.M, B_model_average,'k','markersize',2);

plot( d.A, d.B_MeV_per_nucleon,'b.','markersize',2 );
plot( d.A, B_model,'r.','markersize',2);
plot( e.M, B_model_average,'k','markersize',2);
xlim([0,260])
ylim([0,9])
xlabel('Atomic mass number A','fontsize',fsize);
ylabel('Binding energy per nucleon /MeV','fontsize',fsize);
title('Binding energy per nucleon /MeV','fontsize',fsize);
legend({'NUBASE data','Liquid drop model','Average'},'fontsize',fsize,'location','southeast')
set(gca,'fontsize',fsize)
grid on;
box on;
print( gcf,'binding energy per nucleon vs A.png','-dpng','-r300');
close(gcf);

%%

%Binding energy /MeV per nucleon as a function of Neutron number (N) and
%Proton number (Z)
% https://en.wikipedia.org/wiki/Semi-empirical_mass_formula
%As the name suggests, it is based partly on theory and partly on empirical
%measurements. The theory is based on the liquid drop model proposed by
%George Gamow, which can account for most of the terms in the formula and
%gives rough estimates for the values of the coefficients. It was first
%formulated in 1935 by German physicist Carl Friedrich von Weizscker.
function B = liquid_drop_model( N,Z )

%Constants /MeV
a_v = 15.8;
a_s = 18.3;
a_c = 0.714;
a_a = 23.2;
a_p = 12;

%Mass number
A = Z + N;

%Pairing term
dA = zeros(size(A));
both_even = find(( rem(Z,2)==0 ) & ( rem(N,2)==0 ) );
both_odd = find(( rem(Z,2)~=0 ) & ( rem(N,2)~=0 ) );
dA(both_even) = a_p*A(both_even).^(-3/4);
dA(both_odd) = -a_p*A(both_odd).^(-3/4);

%Compute Binding Energy per nucleon /MeV
B = a_v*A - a_s*A.^(2/3) -a_c*(Z.^2)./(A.^(1/3)) - a_a*((N-Z).^2)./A + dA;
B = B./A;

%End of code