%plot_decay_mode
% Function which loads nuclide data and plots Atomic number (Z) vs
% Mass number (A) for various isotopes, colour coded by decay mode.
% Red is Alpha, Blue is Beta+, Green is Beta- and Magenta is Other
%
% LAST UPDATED by Andy French March 2016

function plot_decay_mode

%Set maximum Z and A-Z values for graph
Zmax = 120;
Nmax = 180;

%Fontsize for plots
fsize = 16;

%log10( Half-life ) threshold for defining an element as stable
stable_half_life = 15;

%

%Determine Z, A and half_life_s data
d = load('nubase.mat');
decay = d.decay_mode_and_intensity;
N = length(d.Z);

%Create figure
figure('name','decay mode of radioactive isotopes','color',[1 1 1]);

%Determine colour map
cmap = colormap;
interp_colormap(500);

%Determine red, green and blue colours appropriate to each decay mode
red = cmap(:,1);
green = cmap(:,2);
blue = cmap(:,3);
plot_col = cell(1,N);
plot_ok = ones(1,N);
for n=1:N
    if (d.stable_nuclei(n)==1) || ( log10( d.half_life_s(n) ) > stable_half_life )
        %Stable nuclei
        plot_col{n} = 'k';
    elseif sum(isnan(decay{n}))~=1
        if strcmp( decay{n}(1),'A' )
            %Alpha decay
            plot_col{n} = 'r';
        elseif strcmp( decay{n}(1:2),'B+' )
            %Beta+ decay
            plot_col{n} = 'g';
        elseif strcmp( decay{n}(1:2),'B-' )
            %Beta- decay
            plot_col{n} = 'b';
        else
            %Other
            plot_col{n} = 'm';
        end
    else
        plot_ok(n) = 0;
    end
end

%

%Plot decay mode
plot(Zmax+10,Nmax+10,'ks','markerfacecolor','k');
hold on;
plot(Zmax+10,Nmax+10,'rs','markerfacecolor','r');
plot(Zmax+10,Nmax+10,'gs','markerfacecolor','g');
plot(Zmax+10,Nmax+10,'bs','markerfacecolor','b');
plot(Zmax+10,Nmax+10,'ms','markerfacecolor','m');
for n=1:N
    if plot_ok(n)==1
        plot(d.Z(n),d.A(n)-d.Z(n),[plot_col{n},'s'],'markersize',1,'markerfacecolor',plot_col{n});
    end
end
legend({'Stable','\alpha','\beta+','\beta-','other'},...
    'fontsize',fsize,'location','eastoutside');
xlabel('Atomic number Z','fontsize',fsize)
ylabel('Number of neutrons (A-Z)','fontsize',fsize)
title('Decay mode of nuclides','fontsize',fsize)
grid on
axis equal
xlim([0,Zmax]);
ylim([0,Nmax]);
plot( linspace(0,Zmax,N), linspace(0,Zmax,N), 'k' );
set(gca,'fontsize',fsize)
box on
print( gcf,'decay mode.png','-dpng','-r300');
close(gcf);

%End of code