%plot_radioactive_decay_curve
% Function which plots the decay curve of radioactive activity (i.e. decays
% per second) vs time.
%
% LAST UPDATED by Andy French March 2016

function plot_radioactive_decay_curve

%Initial activity (decays per time unit)
dN_by_dt0 = 50;

%Half life of isotope
half_life = 70;

%Time unit of half life (options are 'years' or 'seconds')
time_unit = 'second';

%Name of isotope
isotope = 'Protactinium 234';

%Number of half lives to plot
N_half_lives = 10;

%Number of data points
N = 1000;

%Fontsize for graph annotation
fsize = 16;

%

%Generate time data
t = linspace( 0, N_half_lives*half_life, N);

%Generate decay rate data (decays per time unit)
lambda = log(2)/half_life;
dN_by_dt = dN_by_dt0*exp( -lambda * t );

%Plot decay curve
figure('color',[1 1 1],'name','radioactive decay curve');
plot(t,dN_by_dt);
xlabel(['time /',time_unit],'fontsize',fsize);
ylabel(['decay rate / decays per ',time_unit],'fontsize',fsize);
title(['decay rate of ',isotope,' / decays per ',time_unit],'fontsize',fsize);
set(gca,'fontsize',fsize);
grid on;
ylim([0,1.1*dN_by_dt0]);
hold on;
for n=1:N_half_lives
    plot( [n*half_life,n*half_life],[0,1.1*dN_by_dt0],'r--' );
    half_life_rate = dN_by_dt0*exp( -lambda * n*half_life );
    if half_life_rate > 0.01*dN_by_dt0
        plot( [0,N_half_lives*half_life],half_life_rate*[1,1],'r--' );
    end
end
print( gcf, 'radioactive decay curve.png','-dpng','-r300');
close(gcf);

%End of code