%plot_radioactive_decay_curve
% Function which plots the decay curve of relative radioactive activity (i.e. decays
% per second) vs time.
%
% LAST UPDATED by Andy French March 2016

function plot_relative_radioactive_decay_curve

%Half life of isotope
half_life = 5730;

%Time unit of half life (options are 'years' or 'seconds')
time_unit = 'years';

%Name of isotope
isotope = 'Carbon 14';

%Number of half lives to plot
N_half_lives = 10;

%Number of data points
N = 1000;

%Fontsize for graph annotation
fsize = 16;

%

%Generate time data
t = linspace( 0, N_half_lives*half_life, N);

%Generate decay rate data (decays per time unit)
lambda = log(2)/half_life;
dN_by_dt = exp( -lambda * t );

%Plot decay curve
figure('color',[1 1 1],'name','radioactive decay curve');
plot(t,dN_by_dt);
xlabel(['time /',time_unit],'fontsize',fsize);
ylabel('decay rate / decay rate at t=0','fontsize',fsize);
title(['Relative decay rate of ',isotope],'fontsize',fsize);
set(gca,'fontsize',fsize);
grid on;
ylim([0,1.1]);
hold on;
for n=1:N_half_lives
    plot( [n*half_life,n*half_life],[0,1.1],'r--' );
    half_life_rate = exp( -lambda * n*half_life );
    if half_life_rate > 0.01
        plot( [0,N_half_lives*half_life],half_life_rate*[1,1],'r--' );
    end
end
print( gcf, 'relative radioactive decay curve.png','-dpng','-r300');
close(gcf);

%End of code