%pursuit
% N randomly positioned killer snails are created, which move at a fixed
% speed. These will always point towards the curent mouse position. The
% trace of the missiles is plotted, which should be a dynamic 'curve of
% pursuit.'
%
% LAST UPDATED by Andy French 3/12/15

function pursuit

%%% INPUTS %%%

%Define number of killer snails
N = 10;

%Define size of area
L = 1;

%Define snail maximum and minimum speeds
cmax = 1;
cmin = 0.5;

%Set timestep /s
dt = 0.01;

%%

%Create a global variable to store data
global d

%Create a figure
d.fig = figure;

%Set figure functions
set( d.fig,...
    'KeyPressFcn',@keypressfunc,...
    'CloseRequestFcn',@closerequestfunc,...
    'WindowButtonDownFcn',@mouseclickdown,...
    'WindowButtonMotionFcn',@mousedrag,...
    'WindowButtonUpFcn',@mouseclickup,...
    'renderer','painters');

%Initialise animation flag
d.animate = 0;

%Create the initial snail positions and randomize the snail speed
for n=1:N
    d.xsnail(n) = -L + rand*2*L;
    d.ysnail(n) = -L + rand*2*L;
    d.snailspeed(n) = cmin + (cmax-cmin)*rand;
end

%Plot snail positions
d.snails = plot(d.xsnail,d.ysnail,'*');

%Allow graph to be added to
hold on

%Set and freeze axis scale
xlim([-L,L]);
ylim([-L,L]);
axis equal;
axis manual

%Start a loop
d.running = 1;
while d.running ==1
    if d.animate == 1
        %Get mouse position
        cp=get( gca,'currentpoint');
        x = cp(1,1);
        y = cp(1,2);
        
        %Work out for each snail the new velocity vector which points
        %towards the mouse
        theta = atan2( d.ysnail - y, d.xsnail - x );
        vx = -d.snailspeed.*cos(theta);
        vy = -d.snailspeed.*sin(theta);
        
        %Update the snail positions
        d.xsnail = d.xsnail + vx*dt;
        d.ysnail = d.ysnail + vy*dt;
        set( d.snails,'xdata',d.xsnail, 'ydata', d.ysnail );
        
        %Plot the snail trail
        plot(d.xsnail,d.ysnail,'g.','markersize',1);
        
    end
    
        %Flush graphics buffer and pause for time dt
        drawnow;
        pause(dt);
end

%%

function keypressfunc(hObject, eventdata, handles)
global d

%%

function closerequestfunc(hObject, eventdata, handles)
global d
d.running = 0 ;
close(d.fig);

%%

function mouseclickdown(hObject, eventdata, handles)
global d
d.animate = 1;

%%

function mousedrag(hObject, eventdata, handles)
global d

%%

function mouseclickup(hObject, eventdata, handles)
global d
d.animate = 0;

%End of code