%ye_olde_ship_cross_section

function ye_olde_tallship

%Define structure d to be global to the main function
global d

%Initial values (lengths in metres)
d.alpha= 0.5;
d.w = 15.8;
d.h = 12;
d.L = 57;

%Increments resulting from key presses
d.dw = 1;
d.dh = 1;
d.dalpha = 0.05;
d.dL = 1;

%Create (x,y) ship cross section with initial values
d.a = exp(1) * d.w / (2*d.alpha * d.h);
d.b = d.alpha*d.h;

d.N = 100;
d.x = linspace(0, d.h, d.N);
d.y = d.a*d.x.*exp(-d.x/d.b);

%Compute volume of hull in cubic metres
d.V = d.w*d.h*d.L * ( d.alpha*exp(1) - exp( 1 - 1/d.alpha)*(d.alpha + 1)) ;

%Create figure
d.fig = figure('name','Ye-olde-tallship','color',[1 1 1],'KeyPressFcn',@keypress,...
    'units','normalized','position',[0,0,1,1],'Toolbar','none','menubar','none','numbertitle','off');

%Cross section the correct way up, both halves
d.ax1 = subplot(1,2,1);
d.p1=plot(-d.y,d.x,'linewidth',3);
hold on;
d.p2=plot(d.y,d.x,'linewidth',3);
xlabel('y','fontsize',20)
ylabel('x','fontsize',20)
axis equal
xlim([-0.75*d.w,0.75*d.w]);
ylim([0,1.5*d.h]);
title({'Ye-olde-tallship','hull cross-section'},'fontsize',20)
set(d.ax1,'fontsize',20);
grid on

%Half of cross section, tilted by 90 degrees clockwise
d.ax2 = subplot(1,2,2);
d.p3=plot(d.x,d.y,'linewidth',3);
hold on;
xlabel('x','fontsize',20)
ylabel('y','fontsize',20)
axis equal
ylim([0,0.75*d.w]);
xlim([0,1.5*d.h]);
d.tit = title(['w = ',num2str(d.w),' h = ',num2str(d.h),...
    ' L = ',num2str(d.L),' V = ',num2str(d.V),' alpha = ',num2str(d.alpha) ],'fontsize',20);
set(d.ax2,'fontsize',20);
grid on

%%

%Updates the plot
function update_plot
global d

%Update (x,y) ship cross section
d.a = exp(1) * d.w / (2*d.alpha * d.h);
d.b = d.alpha*d.h;
d.x = linspace(0, d.h, d.N);
d.y = d.a*d.x.*exp(-d.x/d.b);

%Compute volume of hull in cubic metres
d.V = d.w*d.h*d.L * ( d.alpha*exp(1) - exp( 1 - 1/d.alpha)*(d.alpha + 1)) ;

%Update plots
axes(d.ax1);
set(d.p1,'xdata', -d.y, 'ydata', d.x );
set(d.p2,'xdata', d.y, 'ydata', d.x );
axes(d.ax2);
set(d.p3,'xdata', d.x, 'ydata', d.y );
set(d.tit,'string',['w = ',num2str(d.w),' h = ',...
    num2str(d.h),' L = ',num2str(d.L),' V = ',num2str(d.V),' alpha = ',num2str(d.alpha)  ]);

%%

%Function which executes when a key is pressed while the ye-olde-tallship
%figure is active
function keypress(fig,evnt)
global d

if strcmp(get(fig,'currentkey'),'a')==1
    d.alpha = d.alpha + d.dalpha;
elseif strcmp(get(fig,'currentkey'),'z')==1
    d.alpha = d.alpha - d.dalpha;
elseif strcmp(get(fig,'currentkey'),'w')==1
    d.w = d.w + d.dw;
elseif strcmp(get(fig,'currentkey'),'s')==1
    d.w = d.w - d.dw;
elseif strcmp(get(fig,'currentkey'),'h')==1
    d.h = d.h + d.dh;
elseif strcmp(get(fig,'currentkey'),'n')==1
    d.h = d.h - d.dh;
elseif strcmp(get(fig,'currentkey'),'l')==1
    d.L = d.L + d.dL;
elseif strcmp(get(fig,'currentkey'),'period')==1
    d.L = d.L - d.dL;
end

%Update plot
update_plot;

%End of code


