%mixer
% A very simple mixer - i.e. a combiner of .mp3 files into a single sound
% file. The relative proportions of each file are specified by the user.
%
% LAST UPDATED by Andy French 16/5/14

function mixer

%Set sample rate /Hz of output
Fs = 44100;

%Display message to command window
disp( '%%%%%%%' )
disp( ' Mixer ' )
disp( '%%%%%%%' )
disp(' ')

%Use standard Windows file navigation box to find .mp3 files. More than one
%can be selected.
disp(' Choose .mp3 file(s) to mix...' )
[filename, pathname] = uigetfile( '*.mp3',...
    'Choose .mp3 files....', ...
    'MultiSelect', 'on');
disp(' ');

%Request user to set relative amplitude proportions of these files.
%Store these in vector mix.
if iscell(filename)
    for n=1:length(filename)
        disp([' Choose mix proportion for file ',filename{n}]);
        i = input(' > ');
        if isempty(i)
            mix(n) = 1;
            disp(' Default mix proportion set at 1')
        else
            mix(n) = i;
        end
        disp(' ')
    end
else
    %Only one or no files chosen. Exit function
    disp(' Only one or zero files chosen. Program exiting.')
    disp(' ');
    return
end

%Initialise mix sample vector
m = [];

%Start clock
t0 = tic;

%Add directory mp3 to path (including all subdirectories)
addpath(genpath('mp3'));

%Load files and record their sample rates. 
%Interpolate if sample rate is not what is defined above.
%Pad mix with zeros if next file longer than the previous.
%Use mix vector to set mix porportions.
for n=1:length(filename)
    
    %Load .mp3 file
    file = [ pathname, filename{n} ];
    [s,fs,Nbits] = mp3read( file );
    dim = size(s);
    
    %Make stereo if not
    if dim(2)==1
        s = [s,s];
    end
    
    %Interpolate if sample rate fs does not equal Fs
    if fs~=Fs
        %Work out time vectors associated with sample, and what it should be
        tt = ( 0 : 1/fs : (dim(1)-1)/fs ).';
        t = ( 0 : 1/Fs : (dim(1)-1)/fs ).';
        
        %Interpolate left and right stereo channels at smaple rate Fs
        left = interp1( tt, s(:,1), t );
        right = interp1( tt, s(:,2), t );
        
        %Recombine interpolated stereo channels
        s = [left,right];
    end
    
    %Pad zeros if new file is different in length to m
    dim = size(s);
    DIM = size(m);
    if dim(1) > DIM(1)
        m = [ m; zeros( dim(1) - DIM(1), 2 ) ];
    elseif dim(1) < DIM(1)
        s = [ s; zeros( DIM(1) - dim(1), 2 ) ];
    end
    
    %Combine s with m
    m = m + mix(n)*s;
end

%Normalize
m = 0.99*m/max(max(abs(m)));

%Save mix
mp3write( m, Fs,...
    ['mix ',strrep( datestr(now),':','-' ),'.mp3'],...
    '--quiet -h -b 192' );
disp([' Mix created in ',num2str(toc(t0)),' seconds.'] )
disp(' ');

%Remove directory mp3 to path (including all subdirectories)
rmpath(genpath('mp3'));

%End code