%mp3graph
% Loads a .mp3 file and plots a graph of the left and right stereo channels
% vs time. Bit rate, sample rate, duration and number of samples are
% also displayed. The graph is saved as a .png file.
%
% LAST UPDATED by Andy french April 2016

function mp3graph

%Set fontsize for graph
fsize = 18;

%

%Add directory mp3 to path (including all subdirectories)
addpath(genpath('mp3'));

%Load .mp3 file
[filename, pathname] = uigetfile( '*.mp3',...
    'Choose .mp3 file to plot', ...
    'MultiSelect', 'off');
file = [ pathname, filename ];
[s,Fs,Nbits] = mp3read( file );

%Remove directory mp3 to path (including all subdirectories)
rmpath(genpath('mp3'));

%Determine time array /s associated with samples
dim = size(s);
t = 0 : 1/Fs : ( dim(1) - 1)/Fs;

%Generate a figure and plot left and right stereo channels
figure('color',[1 1 1],'name','mp3graph')

%Right channel
subplot(2,1,1);
plot( t, s(:,1).' ,'r' );
xlabel('Time /s','fontsize',fsize);
ylabel('Right','fontsize',fsize);
title( { filename,...
    [num2str( ( dim(1) - 1)/Fs ),' seconds. Fs = ',num2str(Fs),...
    ' Hz. Bitrate = ',num2str(Nbits),' kbits/s'],...
    ['Number of samples = ',num2str(dim(1))] },...
    'fontsize',fsize );
grid on;
set(gca,'fontsize',fsize)

%Left channel
subplot(2,1,2);
plot( t, s(:,2).' ,'b' );
xlabel('Time /s','fontsize',fsize);
ylabel('Left','fontsize',fsize);
grid on;
set(gca,'fontsize',fsize)

%Save a .png file
print( gcf, strrep(filename,'.mp3','.png'),'-dpng','-r300' );

%End of code

