%mp3towav
% Batch conversion program for .mp3 files. This will load one or more .mp3
% files and convert them to .wav format.
%
% NOTE the program uses external functions mp3read.m and mp3write.m
% and associated .dll libaries and .exe file. All these are in directory
% mp3. This must be included with this function in order for it to work.
% mp3 library functions have been obtained from the MATLAB File Exchange.
% See individual files for credits etc.
%
% LAST UPDATED by Andy French April 2016

function mp3towav

%Add directory mp3 to path (including all subdirectories)
addpath(genpath('mp3'));

%Display message to command window
disp(' ')
disp(' %%%%%%%%%%%%%%%%%%%%')
disp('  mp3towav converter ')
disp(' %%%%%%%%%%%%%%%%%%%%')
disp(' ')

%Use standard Windows file navigation box to find .mp3 files. More than one
%can be selected.
disp(' Choose .mp3 file(s) to convert to .wav...' )
[filename, pathname] = uigetfile( '*.mp3',...
    'Choose .mp3 files for .wav conversion', ...
    'MultiSelect', 'on');
if iscell(filename)==0
    if filename==0
        return
    else
        filename = {filename};
    end
end

%Start clock
t0 = tic;
t = 0;

%Step through filename and perform .wav conversion.
for n=1:length(filename)
    %Load .mp3 file (s is a vector of sound samples, sampled at
    %frequency Fs Hz, with maximum (signed) amplitude 2^(Nbits-1)
    file = [ pathname, filename{n} ];
    [s,Fs,Nbits] = mp3read( file );
    
    %Convert to .wav
    wavwrite( s, Fs, strrep( file,'.mp3','.wav') );
    
    %Determine current elapsed time
    tt = toc(t0);
    
    %Display completion message
    disp(' ')
    disp([' File ',num2str(n),' of ',num2str(length(filename)),' : ',filename{n}]);
    disp([' Converted to .wav in ', num2str(tt-t),' seconds.'])
    disp([' Total elapsed time is ',num2str(tt),' seconds.']);
    
    %Update current time to enable individual file conversion time
    %calculation
    t=tt;
end

%Display completion message
disp(' ')
disp(' .mp3 file to .wav conversion complete.')
disp(' ')

%Remove directory mp3 from path, including any subdirectories
rmpath(genpath('mp3'));

%End of code





