%siren
% Creates a siren waveform and write this out as a .mp3 file.
%
% LAST UPDATED by Andy French April 2016

function siren

%% Inputs %%

%Define the duration /s
T = 10;

%Define the tone frequencies /Hz
f = [500,700];

%Define the modulation period /s
Tmod = 5;

%Define the freqency modulation percentage
modulation = 30;

%Define the stereo panning period /s
Tpan = 2;

%Define sample frequency /Hz
Fs = 44100;

%

%Display message to command window
disp(' ')
disp(' %%%%%%%%%%%%%')
disp( ' Siren maker ' )
disp(' %%%%%%%%%%%%%')
disp(' ')

%Define time /s array
t = (0 : 1/Fs : T).' ;

%Generate mono signal
s = zeros(length(t),1);
for n=1:length(f)
    F = f(n) * ( 1 + 0.01*modulation*sin(2*pi*t/Tmod) );
    s = s + sin( 2*pi*F.*t ); 
end
s = 0.99*s/max(abs(s));

%Make a stereo vector, incorporating panning
left = 0.5* ( sin( 2*pi*t/Tpan ) + 1 );
right = 1 - left;
s = [ s.*right , s.*left ];

%Add directory mp3 to path (including all subdirectories)
addpath(genpath('mp3'));

%Save .mp3 file
filename = ['siren ',strrep( datestr(now),':','-'),'.mp3'];
mp3write( s, Fs, filename, '--quiet -h -b 192' );
disp( [' Siren created as file ',filename ] )
disp(' ');

%Remove directory mp3 from path (including all subdirectories)
rmpath(genpath('mp3'));

%End of code