%splice
% Splices selected .mp3 files, saving a single file.
%
% LAST UPDATED by Andy French 16/5/14

function splice

%Set sample rate /Hz of output
Fs = 44100;

%Display message to command window
disp(' ')
disp(' %%%%%%%%' )
disp('  Splice ' )
disp(' %%%%%%%%' )
disp(' ')

%Use standard Windows file navigation box to find .mp3 files. More than one
%can be selected.
disp(' Choose .mp3 file(s) to splice...' )
[filename, pathname] = uigetfile( '*.mp3',...
    'Choose .mp3 files....', ...
    'MultiSelect', 'on');
disp(' ');

%Request user to set relative amplitude proportions of these files.
%Store these in vector mix.
if iscell(filename)==0
    %Only one or no files chosen. Exit function
    disp(' Only one or zero files chosen. Program exiting.')
    disp(' ');
    return
end

%Initialise splice sample vector
S = [];

%Start clock
t0 = tic;

%Add directory mp3 to path (including all subdirectories)
addpath(genpath('mp3'));

%Load files and record their sample rates.
%Interpolate if sample rate is not what is defined above.
%Pad mix with zeros if next file longer than the previous.
%Use mix vector to set mix porportions.
for n=1:length(filename)
    
    %Load .mp3 file
    file = [ pathname, filename{n} ];
    [s,fs,Nbits] = mp3read( file );
    disp([' File ',filename{n},' added to splice.'] )
    dim = size(s);
    
    %Make stereo if not
    if dim(2)==1
        s = [s,s];
    end
    
    %Interpolate if sample rate fs does not equal Fs
    if fs~=Fs
        %Work out time vectors associated with sample, and what it should be
        tt = ( 0 : 1/fs : (dim(1)-1)/fs ).';
        t = ( 0 : 1/Fs : (dim(1)-1)/fs ).';
        
        %Interpolate left and right stereo channels at smaple rate Fs
        left = interp1( tt, s(:,1), t );
        right = interp1( tt, s(:,2), t );
        
        %Recombine interpolated stereo channels
        s = [left,right];
    end
    
    %Splice sound vector with S
    S = [S; s];
end

%Save mix
mp3write( S, Fs,...
    ['splice ',strrep( datestr(now),':','-' ),'.mp3'],...
    '--quiet -h -b 192' );
disp([' Splice created in ',num2str(toc(t0)),' seconds.'] )
disp(' ');

%Remove directory mp3 to path (including all subdirectories)
rmpath(genpath('mp3'));

%End code