%wav2mp3
% Batch conversion program for .wav files. This will load one or more .wav
% files and convert them to .mp3 format.
%
% NOTE the program uses external functions mp3read.m and mp3write.m
% and associated .dll libaries and .exe file. All these are in directory
% mp3. This must be included with this function in order for it to work.
% mp3 library functions have been obtained from the MATLAB File Exchange.
% See individual files for credits etc.
%
% LAST UPDATED by Andy French April 2016

function wav2mp3

%Add directory mp3 to path (including all subdirectories)
addpath(genpath('mp3'));

%Display message to command window
disp(' ')
disp(' %%%%%%%%%%%%%%%%%%%')
disp('  wav2mp3 converter ')
disp(' %%%%%%%%%%%%%%%%%%%')
disp(' ')

%Use standard Windows file navigation box to find .wav files. More than one
%can be selected.
disp(' Choose .wav file(s) to convert to .mp3...' )
[filename, pathname] = uigetfile( '*.wav',...
    'Choose .wav files for .mp3 conversion', ...
    'MultiSelect', 'on');
if iscell(filename)==0
    if filename==0
        return
    else
        filename = {filename};
    end
end

%Start clock
t0 = tic;
t = 0;

%Step through filename and perform .mp3 conversion.
for n=1:length(filename)
    %Load .wav file (s is a vector of sound samples, sampled at
    %frequency Fs Hz, with maximum (signed) amplitude 2^(Nbits-1)
    file = [ pathname, filename{n} ];
    [s,Fs,Nbits] = wavread( file );
    
    %Convert to .mp3 (the last bit sets the bit-rate. 128kbits per
    %second is the default. 192 is obviously a little better).
    mp3write( s, Fs, strrep( file,'.wav','.mp3'),'--quiet -h -b 192' );
    
    %Determine current elapsed time
    tt = toc(t0);
    
    %Display completion message
    disp(' ')
    disp([' File ',num2str(n),' of ',num2str(length(filename)),' : ',filename{n}]);
    disp([' Converted to .mp3 in ', num2str(tt-t),' seconds.'])
    disp([' Total elapsed time is ',num2str(tt),' seconds.']);
    
    %Update current time to enable individual file conversion time
    %calculation
    t=tt;
end

%Display completion message
disp(' ')
disp(' .wav file to .mp3 conversion complete.')
disp(' ')

%Remove directory mp3 from path, including any subdirectories
rmpath(genpath('mp3'));

%End of code





