%bestfit_test
% Generates random test data in order to test linear regression
% function bestfit.m

function bestfit_test

%Define x range
xmin = 0;
xmax = 10;

%Define y intercept and gradient of y = m*x + c line
m = -5;
c = 10;

%Define number of data points (x,y pairs)
N = 100;

%Define maximum random y deviation (sample from a uniform distribution)
max_y_dev = 5;

%Define number of data points for line of best fit
Nbest = 1000;

%Define fontsize
fsize = 16;

%%

%Define x and y data
x = linspace( xmin, xmax, N );
y = m*x + c;
y_random = max_y_dev * rand(1,N) - 0.5*max_y_dev;
y = y + y_random;

%Work out line of best fit
[ m,c,xfit,yfit,r ] = bestfit( x,y,Nbest );

%Determine title string
tit_str_1 = [ 'Line of best fit y = ',num2str(m),'x + ',num2str(c) ];
tit_str_2 = [' Product moment corellation coefficient = ',num2str(r)];

%Plot the data, overlaid with the line of best fit
figure('name','line of best fit test','color',[1 1 1] );
plot(x,y,'b+');
hold on;
plot(xfit,yfit,'k-');
grid on;
set(gca,'fontsize',fsize);
title({tit_str_1,tit_str_2},'fontsize',fsize)
xlabel('x','fontsize',fsize)
ylabel('y','fontsize',fsize)

%Print a .PNG file of the graph
dstr = strrep( datestr(now), ':','-');
print( gcf, ['best fit ',dstr,'.png'] ,'-r300', '-dpng' );

%Output x,y data to an Excel file
X{1,1} = 'Line of best fit data';
X{2,1} = 'x';
X{2,2} = 'y';
for n=1:N
    X{2+n,1} = x(n);
    X{2+n,2} = y(n);
end
xlswrite( ['best fit ',dstr,'.xls'], X );

%%

%bestfit
% Function which determines line of best fit to x,y data
%
% [ m,c,xfit,yfit,r ] = bestfit( x,y,N )
%
% x,y vectors defining x,y data inputs
% N number of data points for fitted line of best fit
%
% xfit,yfit vectors defining coordinates of line of best fit
% m,c parameters of line of best fit of form y = m*x + c
% r is the product moment correlation coefficient.

function [ m,c,xfit,yfit,r ] = bestfit( x,y,N )

%Calculate mean parameters
xbar = mean(x);
ybar = mean(y);
x2bar = mean(x.^2);
y2bar = mean(y.^2);
xybar = mean(x.*y);

%Compute variances
Vx = x2bar - xbar^2;
Vy = y2bar - ybar^2;

%Compute covariance
cov_xy = xybar - xbar*ybar;

%Product moment correlation coefficient
r = cov_xy/sqrt( Vx*Vy );

%Determine parameters of line of best fit y = m*x + c 
m = cov_xy/Vx;
c = ybar - m*xbar;

%Define line of best fit
xfit = linspace( min(x), max(x), N );
yfit = m * xfit + c;

%End of code