%binomial_plot
% Script which plots a graph illustrating the binomial distribution.
%
% LAST UPDATED by Andy French 29th August 2015

function binomial_plot

%Define values of N and p
N = 30;

%p values for 2D graphs
p(1) = 0.2;
p(2) = 0.5;
p(3) = 0.9;

%Determine legend string
for m=1:3
    Lstr{m} = ['p = ',num2str(p(m))];
end

%p values for surface of P(x|N,p)
num_p = 200;
pp = linspace(0,1,num_p);

%x values
x = 0:N;

%Calculate probabilities
P = zeros(N+1,3);
PP = zeros(N+1,num_p);
for n=1:N+1
    for m=1:3
        P(n,m) = B( x(n),N,p(m) );
    end
end
for n=1:N+1
    for m=1:num_p
        PP(n,m) = B( x(n),N,pp(m) );
    end
end

%Plot 2D graphs
figure('color',[1 1 1]);
plot( repmat( x',[1,3] ), P,'-' );
hold on
plot( repmat( x',[1,3] ), P,'o' );
xlabel('x','fontsize',12)
ylabel('P(x | N,p)','fontsize',12)
title(['Binomial distribution. N = ',num2str(N)],'fontsize',12)
set(gca,'fontsize',12)
grid on
legend(Lstr,'fontsize',12,'location','EastOutside') 
print( gcf, ['binomial 2d plot N=',num2str(N)],'-dpng','-r300' );
clf

%Plot probability surface
[x,pp] = meshgrid(x,pp);
surf( x, pp, PP.' );
shading interp
xlabel('x')
ylabel('p');
title(['Binomial distribution. N = ',num2str(N)],'fontsize',12)
colorbar
view([-20,48])
print( gcf, ['binomial surface plot N=',num2str(N)],'-dpng','-r300' );
close(gcf);

%%

%Binomial distribution function
function P = B(x,N,p)
P = zeros(size(x));
for n=1:length(x)
    P(n) = nchoosek(N,x(n))*(p^x(n)).*(1-p).^(N-x(n)) ;
end

%End of code