%normal_plot
% This plots a standardized normal distribution and its cumulative
% function.
%
% LAST UPDATED by Andy French September 2015

function normal_plot

%Graph fontsize
fsize = 18;

%Define z values
z = linspace(-4,4,1000);

%

%Compute probability density function
PDF = (1/sqrt(pi))*exp( -0.5*z.^2 );

%Compute CDF
CDF = zeros(size(z));
CDF( z>0 ) = 0.5 + 0.5*erf( z(z>0)/sqrt(2) );
CDF( z<0 ) = 0.5 - 0.5*erf( -z(z<0)/sqrt(2) );

%Compute inverse CDF
PHI = linspace(0,1,1000);
Z = sqrt(2)*erfinv(2*PHI-1);

%Compute error function
E = erf(z);

%Compute inverse of error function
x=linspace(-1,1,1000);
iE = erfinv(x);

%Normal PDF
figure('color',[ 1 1 1],'name','normal plot');
plot(z,PDF,'linewidth',2);
set(gca,'fontsize',fsize );
ylim([0,0.6])
grid on;
xlabel('z','fontsize',fsize)
ylabel('p(z)','fontsize',fsize)
title('Standard normal distribution','fontsize',fsize)
print( gcf,'normal PDF','-dpng','-r300' )
clf;

%Normal CDF
plot(z,CDF,'linewidth',2);
grid on;
xlabel('z','fontsize',fsize)
ylabel('CDF(z)','fontsize',fsize)
title('Standard cumulative normal distribution','fontsize',fsize)
set(gca,'fontsize',fsize );
print( gcf,'normal CDF','-dpng','-r300' )
clf;

%Normal CDF & inverse
plot(z,CDF,'b-','linewidth',2);
hold on;
plot(PHI,Z,'r-','linewidth',2);
grid on;
xlabel('z','fontsize',fsize)
title('Standard cumulative normal distribution','fontsize',fsize)
legend({'CDF','inverse CDF'},'fontsize',fsize,'location','Eastoutside')
set(gca,'fontsize',fsize );
axis equal
ylim([-2,2])
xlim([-2,2])
print( gcf,'normal CDF & inverse','-dpng','-r300' )
clf;

%Error function
plot(z,E,'b-','linewidth',2);
hold on;
plot(x,iE,'r-','linewidth',2);
set(gca,'fontsize',fsize );
axis equal
ylim([-2,2])
xlim([-2,2])
grid on;
xlabel('x','fontsize',fsize)
title('Error function erf(x)','fontsize',fsize)
legend({'erf(x)','inverse erf(x)'},'fontsize',fsize,'location','Eastoutside')
print( gcf,'error function','-dpng','-r300' )
close(gcf);

%End of code