%poisson_plot
% Plots a few examples of a Poisson distribution
%
% LAST UPDATED by Andy French 29th August 2015

function poisson_plot

%Define Poisson mean event rates
lamda(1) = 10;
lamda(2) = 30;
lamda(3) = 100;

%Fontsize for graphs
fsize = 12;

%

%Determine graph legend
for n=1:3
    Lstr{n} = ['\lambda = ',num2str(lamda(n))];
end

%Define range of x
N = round( 1.5*max(lamda) );
x=0:N;

%Compute (Poisson) probabilities
P = zeros(N,3);
for n=1:N+1
    for m=1:3
        P(n,m) = exp(-lamda(m))*(lamda(m))^(x(n))/factorial(x(n));
    end
end

%Plot graph
figure('name','poisson plot','color',[1 1 1]);
plot( repmat( x',[1,3] ), P,'-' );
hold on;
plot( repmat( x',[1,3] ), P,'o' );
xlabel('x','fontsize', fsize );
ylabel('P(x | \lambda)','fontsize', fsize );
set(gca,'fontsize', fsize)
title('Poisson distribution','fontsize', fsize );
legend( Lstr, 'location','Eastoutside','fontsize', fsize );
grid on
print( gcf, 'poisson','-dpng','-r300' );
close(gcf);

%End of code