%countdown
% Function which counts down a timer in seconds.
% The result is displayed to the screen in a figure window.
%
% Syntax: countdown(N,f), countdown(N) or countdown.
% With no inputs, the timer is ten seconds.
% N is the number of seconds to count down.
% f is the fraction of screen dimensions. 1 means full screen. Default is 0.2
%
% LAST UPDATED by Andy French April 2016

function countdown(varargin)

% Default fraction of screen size corresponding to timer box
sfrac = 0.2;

%Get input, or set default if no input provided
if nargin == 0
    N = 10;
elseif nargin == 1
    N = varargin{1};
else
    N = varargin{1};
    sfrac = varargin{2};
end

%Get screen dimensions in pixels
screensize = get(0,'ScreenSize');
xpixels = screensize(3);
ypixels = screensize(4);

%Define position vector of countdown timer in pixels
a = floor( sfrac*xpixels );
b = floor( sfrac*ypixels );
p = [ 0.5*xpixels - a/2, 0.5*ypixels - b/2, a,b ];

%Define a global variable which describes the state of the time figure.
% f = 0 means closed, f = 1 means open. A global variable allows the figure
% closing function to communicate that the figure is closed to the rest of
% the program.
global f
f = 1;

%Create figure and axes within it
fig = figure('name','Countdown',...
    'Toolbar','None','Menubar','None','units','pixels',...
    'Numbertitle','off','Resize','off','CloseRequestFcn',@figclose );
set(fig,'position',p);
axes('units','pixels','position',[0,0,a,b]);
axis off
xlim([0,a]);
ylim([0,b]);

%Initialize timer text with figure
t = text( 0.1*a,0.5*b,num2str(N),'fontsize',sfrac*700  );

%Loop countdown
while ( N > 0 ) && ( f == 1)
    
    %Pause for one second
    pause(1);
    
    %Decrement counter
    N = N - 1;
    
    %Update figure, unless it has already been closed
    if f == 1
        set( t,'string',num2str(N));
        
        %Set figure text colour to be red if N < 10
        if N < 10
            set( t,'color',[1,0,0] );
        end
    end
end

%Close figure, unless it has already been closed
if f == 1
    close(fig);
end

%%

%Figure close function
function figclose( fig,evnt )
global f
f = 0;
closereq;

%End of code