%timealive
% Function which computes your time alive, to the nearest second and then
% displays the results to the command window.
%
% Key result is: 
% datenum('09-Apr-2016 12:34:56') - datenum('12-May-1984 12:34:56') 
% will give you the number of days between the dates above.
%
% LAST UPDATED by Andy French April 2016

function timealive

%Display initial message to command window
disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp(' Calculate how long you have been alive!')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp(' ')

%Request date of birth
disp(' State your date of birth in the format similar to 12-May-1984 12:34:56 ' )
birth = input(' > ','s') ;

%If birth is empty, set a default birth
if isempty(birth)
    birth = '12-May-1984 12:34:56';
    disp(' Default birth of 12-May-1984 12:34:56 is used.')
end

%Determine the current date string
date_now = datestr(now);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% %Test the program by hard coding your next birthday. You will see the
% %effects of leap years! Uncomment this part of the code to apply the test.
% birth = '12-May-0384';
% date_now = datestr('12-May-2016'); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Convert dates to serial date numbers, and work out the difference.
%This will return the number of days that you have been living for
dt = datenum( date_now ) - datenum(birth) ;
total_days = dt;

%Extract elapsed time in years, months, days etc
years_elapsed = floor( dt /365 );
dt = dt - years_elapsed*365;
months_elapsed = floor( dt / (365/12) );
dt = dt - months_elapsed*365/12;
days_elapsed = floor(dt);
dt = dt - days_elapsed;
hours_elapsed = floor( 24*dt );
dt = 24*dt - hours_elapsed;
minutes_elapsed = floor( dt*60 );
dt = 60*dt - minutes_elapsed;
seconds_elapsed = 60*dt;

%Display results in command window
disp(' ')
disp( [' ',num2str(years_elapsed),' years, ',num2str(months_elapsed),' months, ',num2str(days_elapsed),...
    ' days, ',num2str(hours_elapsed),' hours, ',num2str(minutes_elapsed),' minutes and ',...
    num2str(seconds_elapsed),' seconds'] );
disp([' have elapsed since your birth on ',birth ] );
disp(' ')
disp([' Overall you have been alive for ',num2str(total_days),' days.'])
disp([' This is ',num2str(total_days*24*3600/1e9),' billion seconds.' ])
disp(' ')

%End of code